@@ -1,15 +1,20 @@
-box.heresy<-function(x,y,uinner,linner=uinner,ulim,llim=ulim,boxwidth=NA,
- intervals=FALSE,arrow.cap=NA,pch=22,main="",xlab="",ylab="",xaxlab=NA,
- col="white",do.first=NULL,...) {
+box.heresy<-function(x,y,uinner,linner,ulim,llim=ulim,
+ boxwidth=NA,intervals=FALSE,arrow.cap=NA,pch=22,main="",xlab="",
+ ylab="",xaxlab=NA,col="white",do.first=NULL,...) {
 
  if(missing(y)) {
   y<-x
   x<-1:length(y)
  }
+ if(missing(llim)) llim<-ulim
+ if(missing(linner)) linner<-uinner
  if(is.na(xaxlab[1])) xaxlab<-x
+ # if dispersion is specified in intervals, convert to absolute values
  if(intervals) {
   ulim<-y+ulim
   llim<-y-llim
+  uinner<-y+uinner
+  linner<-y-linner
  }
  if(is.na(boxwidth[1])) {
   if(length(x) > 1) xrange<-range(x)
@@ -24,16 +29,13 @@ box.heresy<-function(x,y,uinner,linner=uinner,ulim,llim=ulim,boxwidth=NA,
   x<-cumsum(boxwidth*2)+cumsum(rep(xspace,nboxes))
   xlim<-c(xspace+boxwidth[1]/2,x[nboxes]+boxwidth[nboxes]+xspace)
  }
- plot(x,y,xlim=xlim,ylim=range(c(llim,ulim)),
-  main=main,xlab=xlab,ylab=ylab,type="n",xaxt="n")
+ plot(x,y,xlim=xlim,ylim=range(c(llim,ulim)),main=main,
+ xlab=xlab,ylab=ylab,type="n",xaxt="n")
  if(!is.null(do.first)) eval(parse(text=do.first))
  axis(1,at=x,labels=xaxlab)
  if(is.na(arrow.cap)) arrow.cap<-boxwidth/diff(par("usr")[1:2])
+ # upper and lower limits have already been converted
  dispersion(x,y,ulim,llim,intervals=FALSE,arrow.cap=arrow.cap,...)
- if(intervals) {
-  uinner<-y+uinner
-  linner<-y-linner
- }
  rect(x-boxwidth,linner,x+boxwidth,uinner,col=col)
  points(x,y,pch=pch)
 }
